BUILD_BIT='64bit'
BUILD_CPU='unknown'
BUILD_DATE='2019-03-31'
BUILD_MACHINE='aarch64'
BUILD_OS='Linux   '
BUILD_TIME='21:42'
BUILT_BY='builduser'
BUILT_ON='leming'
COMPILER_VERSION='aarch64-unknown-linux-gnu-gcc (GCC) 8.2.1 20180831'
CYTHON_VERSION='0.29.6'
LINKER_VERSION='GNU ld (GNU Binutils) 2.31.1'
PYTHON_VERSION='2.7.16'
RELEASE_BUILD=True
lib_pycairo='1.18.0'
lib_pygobject='2.28.7'
lib_pygtk='2.24.0'
lib_vpx='1.8.0'
lib_x11='1.6.7'
lib_x264='0.157.2945 72db437'
lib_x265='3.0'
lib_xcomposite='0.4.5'
lib_xdamage='1.1.5'
lib_xext='1.3.4'
lib_xfixes='5.0.3'
lib_xkbfile='1.1.0'
lib_xrandr='1.5.2'
lib_xtst='1.2.3'
